#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章1節 \
#'   誤差を考慮した解析 \
#'   Green3-2-1a.R
#' author: "Masahiko Katase"
#' date: "2021/3/15"
#' ---

library(readxl)
df <- read_excel("Green3-2.xlsx", sheet = "21-futoubunsan1")
df <- data.frame(df)

# グラフ化、モデル 
plot(df, log = "x")

mdl1 <- y ~ y0 +(yinf - y0) / (1 + (x50 / x) ^ b)
mdl2 <- log(y) ~ log(y0 +(yinf - y0) / (1 + (x50 / x) ^ b))

#'# 表示2.1.7 不等分散を無視した解析（p.74）

nls_out1 <- nls(formula = mdl1, 
                start = list(y0 = 18, 
                             yinf = 100,
                             x50 = 30,
                             b = 1),
                data = df)
print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
cov2cor(vcov(nls_out1))     # 推定値の相関

plot(df, log = "x")
lines(df$x, predict(nls_out1), type = "l")

#'# 表示2.1.7 不等分散を考慮した解析（p.74）

nls_out2 <- nls(formula = mdl2, 
                start = list(y0 = 18, 
                             yinf = 100,
                             x50 = 30,
                             b = 1),
                data = df)
print(nls_out2)　　　　　　 # 結果の要約 
summary(nls_out2)           # 推定値、近似標準誤差、t値
confint(nls_out2)　　　　　 # 推定値の区間推定
cov2cor(vcov(nls_out2))     # 推定値の相関

plot(df, log = "x")
lines(df$x, 2.71828^predict(nls_out2), type = "l")
