#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章2節 \
#'   効力比 \
#'   Green3-2-2.R
#' author: "Masahiko Katase"
#' date: "2021/5/1"
#' ---

library(readxl)

df <- read_excel("Green3-2.xlsx", sheet = "22-kouryokuhi")
df <- data.frame(df)

#'# 表示2.2.7 効力比モデルを確認するための解析、表示2.2.10 JMP 「非線形回帰」の結果(1)（p.87）
mdl <- y ~ ifelse(group == "A1",
       　　　　　 y0 + (yinf - y0) / (1 + (x50 / x) ^ b),
                  (y0 + dy0) + ((yinf + dyinf) - (y0 + dy0)) / (1 + ((x50 + dx50) / x) ^ (b + db)))
                 
nls_out <- nls(formula = mdl, 
               start = list(y0  = 0.8, yinf  = 1.8, x50  = 0.5, b  = 1,
                            dy0 = 0,   dyinf = 0,   dx50 = 0,   db = 0),
               data = df)

print(nls_out)　　　　　　 # 結果の要約 
summary(nls_out)           # 推定値、近似標準誤差、t値
cov2cor(vcov(nls_out))     # 推定値の相関

cbind("x" = df$x, "y" = df$y, "y-hat" = predict(nls_out), 
      "e" = df$y - predict(nls_out) )

#'# 表示2.2.7 効力比モデルを確認するための解析、表示2.2.11 記録したモデル（p.88）
# フルモデルの保存
full_mdl <- nls_out

# dyinf=0 に固定、その初期値を消去、nlsを実行、結果を保存、モデルの比較
dyinf <-  0
nls_out <- nls(formula = mdl, 
               start = list(y0  = 0.8, yinf  = 1.8, x50  = 0.5, b  = 1,
                            dy0 = 0, 　　　　　　   dx50 = 0,   db = 0),
               data = df)
summary(nls_out)
dyinf0_mdl <- nls_out
anova(dyinf0_mdl, full_mdl)  

# さらに dy0=0 に固定、その初期値を消去、nlsを実行、結果を保存、モデルの比較
dy0 <- 0
nls_out <- nls(formula = mdl, 
               start = list(y0  = 0.8, yinf  = 1.8, x50  = 0.5, b  = 1,
               　　                                 dx50 = 0,   db = 0),
               data = df)
summary(nls_out)
dy00_mdl <- nls_out
anova(dy00_mdl, dyinf0_mdl) 

# さらに db=0 に固定、その初期値を消去、nlsを実行、結果を保存、モデルの比較
db <- 0
nls_out <- nls(formula = mdl, 
               start = list(y0  = 0.8, yinf  = 1.8, x50  = 0.5, b 　 = 1, 
                            　　　　　　　　　　　　dx50 = 0),
               data = df)
summary(nls_out)
db0_mdl <- nls_out 
anova(db0_mdl, dy00_mdl)  

#'# 表示2.2.10 JMP 「非線形回帰」の結果（p.90）
mdl1 <- y ~ y0 + (yinf - y0) / (1 + (x50 /(x1 + c * x2) ) ^ b)

nls_out1 <- nls(formula = mdl1,
                start = list(y0 = 0.8, yinf = 1.8, x50 = 0.5, b  = 2, c = 1),
                data = df)

print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
confint(nls_out1)　　　　　 # 推定値の区間推定
cov2cor(vcov(nls_out1))     # 推定値の相関

cbind("x1" = df$x1, "x2" = df$x2, "y" = df$y, "y-hat" = predict(nls_out1), 
      "e" = df$y - predict(nls_out1))

