#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章3節 \
#'   併用効果（相乗・拮抗） \
#'   Green3-2-3b.R
#' author: "Masahiko Katase"
#' date: "2021/3/25"
#' ---

library(readxl)  # read_excel
library(dplyr)   # case_when

df <- read_excel("Green3-2.xlsx", sheet = "23-heiyo")
df <- data.frame(df)

#'# 表示2.3.13 JMP の「非線形回帰」による解析結果（p.104）
mdl <- function(t, x1, x2, y0, x50, b, ci, cc){
  case_when(
    t == "multi"  ~ y0 * (1 - (1 / (1 + ((x50 * ci)/(x1 + cc * x2)) ^ b))),
    t == "single" ~ y0 * (1 - (1 / (1 + ((x50) / (x1 + cc * x2)) ^ b)))
  )
}

nls_out <- nls(y ~ mdl(t, x1, x2, y0, x50, b, ci, cc), 
               start = list(y0 = 120, b = 2, x50 = 2, cc = 0.655, ci = 1),
               data = df)

print(nls_out)　　　　　　 # 結果の要約 
summary(nls_out)           # 推定値、近似標準誤差、t値
confint(nls_out)           # 区間推定
cov2cor(vcov(nls_out))     # 推定値の相関

cbind(df, "y-hat" = predict(nls_out), "e" = df$y - predict(nls_out))

#'# 表示 2.3.14 記録したモデル（p.104）
# フルモデルを記録
full_mdl <- nls_out

# CI = 1、その初期値を消去してnlsを実行、結果を保存、モデルの比較
ci <- 1
nls_out <- nls(y ~ mdl(t, x1, x2, y0, x50, b, ci, cc), 
               start = list(y0 = 120, b = 2, x50 = 2, cc = 0.655),
               data = df)


ci0_mdl <- nls_out 
anova(ci0_mdl, full_mdl)  
