#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章4節 \
#'   モデルの探索（複数の曲線の同時あてはめ） \
#'   Green3-2-4a.R
#' author: "Masahiko Katase"
#' date: "2021/5/1"
#' ---

library(readxl) # read_excel

df <- read_excel("Green3-2.xlsx", sheet = "24-fukusu")
df <- data.frame(df)

#'# 表示2.4.2 ソルバーによる解析表（p.107）投与群ごとのあてはめ（full モデル）
mdl <- y ~ ifelse(group == "cont",
                  yinf1 + (y01 - yinf1) * exp(-B1 * x),
                  ifelse(group == "low",
                         yinf2 + (y02 - yinf2) * exp(-B2 * x),
                         ifelse(group == "middle",
                                yinf3 + (y03 - yinf3) * exp(-B3 * x),
                                yinf4 + (y04 - yinf4) * exp(-B4 * x)
                               )
                        )
                  )

nls_out <- nls(formula = mdl, 
               start = list(y01 = 0, y02 = 0, y03 = 0, y04 = 0,
                            yinf1 = 1.9, yinf2 = 2.1, yinf3 = 2.2, yinf4 = 2.4,
                            B1 = 1, B2 = 1, B3 = 1, B4 = 1),
               data = df)

print(nls_out)　　　　                　　 # 結果の要約 
summary(nls_out)                           # 推定値、近似標準誤差、t値
confint(nls_out)                           # 区間推定
round(cov2cor(vcov(nls_out)), digits = 3)  # 推定値の相関