#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章4節 \
#'   モデルの探索（複数の曲線の同時あてはめ） \
#'   Green3-2-4c.R
#' author: "Masahiko Katase"
#' date: "2021/5/1"
#' ---

library(readxl) # read_excel
library(dplyr)  # case_when

df <- read_excel("Green3-2.xlsx", sheet = "24-fukusu")
df <- data.frame(df)

#'# 表示2.4.3 y0 を共通とするモデルの解析結果
mdl <- function(g, x,
                yinf1, y0, B1, 
                yinf2, 　　B2, 
                yinf3, 　　B3, 
                yinf4, 　　B4){
  case_when(
    g == "cont"   ~ yinf1 + (y0 - yinf1) * exp(-B1 * x),
    g == "low"    ~ yinf2 + (y0 - yinf2) * exp(-B2 * x),
    g == "middle" ~ yinf3 + (y0 - yinf3) * exp(-B3 * x),
    g == "high"   ~ yinf4 + (y0 - yinf4) * exp(-B4 * x)
  )
}

nls_out <- nls(y ~ mdl(group, x, 
                       yinf1, y0, B1, 
                       yinf2, 　　B2, 
                       yinf3, 　　B3, 
                       yinf4, 　　B4), 
               start = list(yinf1 = 1.9, y0 = 0, B1 = 1,
                            yinf2 = 2.1, 　　　　B2 = 1,
                            yinf3 = 2.2, 　　　　B3 = 1,
                            yinf4 = 2.4, 　　　　B4 = 1),
               data = df)

print(nls_out)　　　　                　　 # 結果の要約 
summary(nls_out)                           # 推定値、近似標準誤差、t値
confint(nls_out)                           # 区間推定
round(cov2cor(vcov(nls_out)), digits = 3)  # 推定値の相関

nls_out3 <- nls_out
