#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章4節 \
#'   モデルの探索（複数の曲線の同時あてはめ） \
#'   Green3-2-4f.R
#' author: "Masahiko Katase"
#' date: "2021/5/1"
#' ---

library(readxl) # read_excel
library(dplyr)  # case_when

df <- read_excel("Green3-2.xlsx", sheet = "24-fukusu")
df <- data.frame(df)

#'# 表示2.4.5 y∞ と B 間に直線を仮定したモデルモデルのあてはめ
mdl <- function(g, x, k, y0, yinf1, yinf2, yinf3, yinf4){
  case_when(
    g == "cont"   ~ yinf1 + (y0 - yinf1) * exp(k / (y0 - yinf1) * x),
    g == "low"    ~ yinf2 + (y0 - yinf2) * exp(k / (y0 - yinf2) * x),
    g == "middle" ~ yinf3 + (y0 - yinf3) * exp(k / (y0 - yinf3) * x),
    g == "high"   ~ yinf4 + (y0 - yinf4) * exp(k / (y0 - yinf4) * x)
  )
}

nls_out <- nls(y ~ mdl(group, x, k, y0, yinf1, yinf2, yinf3, yinf4), 
               start = list(k = 1,
                            y0 = 0,
                            yinf1 = 1.9, 
                            yinf2 = 2.1, 　　　
                            yinf3 = 2.2, 　　　
                            yinf4 = 2.4),
               data = df)

print(nls_out)　　　　                　　 # 結果の要約 
summary(nls_out)                           # 推定値、近似標準誤差、t値
confint(nls_out)                           # 区間推定
round(cov2cor(vcov(nls_out)), digits = 3)  # 推定値の相関

nls_out4 <- nls_out


#'# 表示2.4.7 分散分析表のまとめ
#（Compile Report では無効）
#+ eval = FALSE	

anova(nls_out3, nls_out2)

anova(nls_out33, nls_out3)

anova(nls_out333, nls_out3)

anova(nls_out4, nls_out3)

