#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章5節 \
#'   薬物動態の解析 \
#'   Green3-2-5a.R
#' author: "Masahiko Katase"
#' date: "2021/5/4"
#' ---

#'# 表示2.5.2 血液薬物量の時間変化(1)（p.120）

fy <- function(t, a, b1, b2){
  a * b1 / (b1 - b2) * (-exp(-b1 * t) + exp(-b2 * t))
}

ftmax <- function(a, b1, b2) {
  ifelse(b1 == b2,
         1 / b1,
          (log(b1) - log(b2)) / (b1 - b2))
}

fcmax <- function(a, b1, b2) {
  ifelse(b1 == b2,
         a / 2.71928,
         a * (b1 / b2) ^ (-1 / (b1 / b2 - 1)))
}

fauc <- function(a, b2) {a / b2}

a  <- 100
b1 <- 0.10
b2 <- c(0, 0.02, 0.05, 0.09999, 0.20)

plot(NA, xlim = c(0, 50), ylim = c(0, 100), xlab = "t", ylab = "y")
for (i in 1:5) {
  curve(fy(x, a, b1, b2[i]), col = i, add = TRUE)
  tm <- ftmax(a, b1, b2[i])
  cm <- fcmax(a, b1, b2[i])
  segments(tm, 0, tm, cm, lty = 2)
  segments(0, cm, tm, cm, lty = 2)
}

b2 <- c(0.02, 0.05, 0.09999, 0.20)
tm <- ftmax(a, b1, b2)
cm <- fcmax(a, b1, b2)
cbind(a = rep(100, 4), b1 = rep(0.1, 4), b2 = b2, tmax = tm, Cmax = cm)

#'# 表示2.5.2 血液薬物量の時間変化(2)（p.122）
a  <- c( 100,  100,  100,  100,   50)
b1 <- c(2.00, 1.00, 0.50, 0.25, 1.00)
b2 <- c(4.00, 2.00, 1.00, 0.50, 0.50)

plot(NA, xlim = c(0, 5), ylim = c(0, 30), xlab = "t", ylab = "y")
for (i in 1:5) {
  curve(fy(x, a[i], b1[i], b2[i]), col = i, add = TRUE)
}

tm <- round(ftmax(a, b1, b2), digits = 3)
cm <- round(fcmax(a, b1, b2), digits = 3)
au <- round(fauc(a,b2), digits = 3)
mx <- rbind(a = a, b1 = b1, b2 = b2, tmax = tm, Cmax = cm, AUC = au)
nm <- vector()
for (i in 1:5) nm <- c(nm, paste("(", i, ")")) 
colnames(mx) <- nm
print(mx)

t   <- c(0, 0.1, 0.2, 0.4, 0.7, 1, 1.5, 2, 2.5, 3, 3.5, 4, 5)
mx <- cbind(t)
for (i in 1:5) {
  vt <- fy(t, a[i], b1[i], b2[i])
  vt <- round(vt, digits = 3)
  mx <- cbind(mx, vt)
}
colnames(mx) <- c("t", nm)
print(mx)
