#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章5節 \
#'   薬物動態の解析 \
#'   Green3-2-5b.R
#' author: "Masahiko Katase"
#' date: "2021/5/4"
#' ---

library(readxl) # read_excel

df <- read_excel("Green3-2.xlsx", sheet = "25-PK1")
df <- data.frame(df)

plot(df$t, df$y)

ftmax <- function(a, b1, b2) {
  ifelse(b1 == b2,
         1 / b1,
         (log(b1) - log(b2)) / (b1 - b2))
}

fcmax <- function(a, b1, b2) {
  ifelse(b1 == b2,
         a / 2.71928,
         a * (b1 / b2) ^ (-1 / (b1 / b2 - 1)))
}

fauc <- function(a, b2) {a / b2}

## 表示2.5.4 データとExcelソルバーによる解析結果（123頁）

mdl<- y ~ a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t))

# 初期値１　b1 > b2
nls_out1 <- nls(formula = mdl, 
                 start = list(a = 10, b1 = 0.5, b2 = 0.2),
                 data = df)
summary(nls_out1)
a  <- coef(nls_out1)[1]
b1 <- coef(nls_out1)[2]
b2 <- coef(nls_out1)[3]
tm <- ftmax(a, b1, b2)
cm <- fcmax(a, b1, b2)
au <- fauc(a, b2)
mx <- rbind(a = a, b1 = b1, b2 = b2, tmax = tm, Cmax = cm, AUC = au)
colnames(mx) <-  "Initial values-1"
print(mx)

t <- seq(0, 25, length = 100)
y <- a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t))
plot(df$t, df$y, xlim = c(0, 25), ylim = c(0, 6))
lines(t, y, type = "l")

yhat <- fitted(nls_out1)
e    <- abs(residuals(nls_out1))
lm_out <- lm(e ~ yhat)
plot(fitted(nls_out1), abs(residuals(nls_out1)), xlim = c(0, 6), ylim = c(0,0.6))
abline(lm_out)

# 初期値２　b1 < b2
nls_out2 <- nls(formula = mdl, 
                 start = list(a = 25, b1 = 0.2, b2 = 0.5),
                 data = df)
summary(nls_out2)
a  <- coef(nls_out2)[1]
b1 <- coef(nls_out2)[2]
b2 <- coef(nls_out2)[3]
tm <- ftmax(a, b1, b2)
cm <- fcmax(a, b1, b2)
au <- fauc(a, b2)
mx <- rbind(a = a, b1 = b1, b2 = b2, tmax = tm, Cmax = cm, AUC = au)
colnames(mx) <-  "Initial values-2"
print(mx)