#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部2章5節 \
#'   薬物動態の解析 \
#'   Green3-2-5c.R
#' author: "Masahiko Katase"
#' date: "2021/5/4"
#' ---

library(readxl) # read_excel

df <- read_excel("Green3-2.xlsx", sheet = "25-PK1")
df <- data.frame(df)

#'# 表示2.5.5 JMP によ解析結果（左 y、右log(y)（p.124）

mdl1 <- y ~ a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t))
mdl2 <- log10(y) ~ log10(a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t)))

# モデル１
nls_out1 <- nls(formula = mdl1, 
                 start = list(a = 10, b1 = 0.5, b2 = 0.2),
                 data = df)
summary(nls_out1)
# confint(nls_out1)
cov2cor(vcov(nls_out1))

a  <- coef(nls_out1)[1]
b1 <- coef(nls_out1)[2]
b2 <- coef(nls_out1)[3]
t <- seq(0, 25, length = 100)
y <- a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t))
plot(df$t, df$y)
lines(x = t, y = y, type = "l")

# モデル２
nls_out2 <- nls(formula = mdl2, 
                 start = list(a = 10, b1 = 0.5, b2 = 0.2),
                 data = df)
summary(nls_out2)
confint(nls_out2)
cov2cor(vcov(nls_out2))

a  <- coef(nls_out2)[1]
b1 <- coef(nls_out2)[2]
b2 <- coef(nls_out2)[3]
y <- log(a * (b1 / (b1 - b2)) * (-exp(-b1 * t) + exp(-b2 * t)))
plot(df$t, log(df$y))
lines(x = t, y = y, type = "l")
